@@ -8,7 +8,7 @@
 # /_/ /_/\____/_.___/\____/_/ /_/_/\___/_/|_|\___/_/____/ 
 
 __title__   = 'hobonickels'
-__version__ = '0.3'
+__version__ = '1.0'
 __author__  = '@c0ding'
 __repo__    = 'https://github.com/c0ding/hobonickels-api'
 __license__ = 'Apache v2.0 License'
@@ -17,5 +17,5 @@ import hobonickels_utils
 from hobonickels_api import (
 	about, difficulty, hashrate, block_count, total_coins, addressbalance,
 	addresstohash, checkaddress, getreceivedbyaddress, getsentbyaddress,
-	hashpubkey, hashtoaddress, translate_address, to_btc
+	hashpubkey, hashtoaddress, translate_address, generate_address, to_btc
 )
